@@ -8,10 +8,10 @@
 #' @param prefs An N × J matrix of numerical stimulus ratings or preference scores. These data are only required by the `"HBAM_R_MINI"` model and will be ignored when fitting other models.
 #' @param allow_miss Integer specifying how many missing stimulus positions should be accepted for an individual still to be included in the analysis. Defaults to 2.
 #' @param req_valid Integer specifying how many valid observations to require for a respondent to be included in the analysis. The default is `req_valid = J - allow_miss`, but if specified, `req_valid` takes precedence.
-#' @param req_unique Integer specifying how may unique positions on the ideological scale each respondent is required to have used when placing the stimuli in order to be included in the analysis. The default is `req_unique = 2`.
+#' @param req_unique Integer specifying how many unique positions on the ideological scale each respondent is required to have used when placing the stimuli in order to be included in the analysis. The default is `req_unique = 2`.
 #' @param B Scalar specifying the upper bound of the survey scale after centering. If not supplied, this information will be inferred from the data.
 #' @param group_id Vector of length N identifying which group each respondent belongs to. The format can be factor, character, integer, or numeric. Respondents with NAs on `group_id` will be dropped when `group_id` is supplied. These data are only required by models with `"MULTI"` in their name and will be ignored when fitting other models.
-#' @param quiet Logical: Should information about the data be printed to the console? Defaults to `TRUE`.
+#' @param quiet Logical: Should information about the data be printed to the console? Defaults to `FALSE`.
 #' @return A list of data to be used by `hbam()` or `fbam()`. The returned list includes the logical vector `keep`, which identifies the rows in the original data that have been kept for further analysis. The stimuli data are stored in a vector as a long-form sparse matrix. If the stimuli data include column-names, these will be preserved for later use.
 #' @examples
 #' # Loading and re-coding ANES 1980 data:
@@ -122,7 +122,7 @@ prep_data <- function(self = NULL, stimuli,
   stimuli <- stimuli[keep, ]
   self <- self[keep]
   group_id <- group_id[keep]
-  if(!is.null(group_id)) {
+  if (!is.null(group_id_fac)) {
     group_id_fac <- group_id_fac[keep]
   }
 
@@ -171,7 +171,7 @@ prep_data <- function(self = NULL, stimuli,
 
   if (!quiet) {
     writeLines(paste0(
-"Summary of prepared data (values for supplied data in paretheses)
+"Summary of prepared data (values for supplied data in parentheses)
 - Number of respondents: ", nrow(stimuli), " (", N_orig, ")
 - Number of stimuli: ", ncol(stimuli), " (", length(stimulicols), ")
 - Number of stimuli obs.: ", length(stimuli_vec), " (", N_obs_orig, ")
